StandardHttpClassifier

Struct StandardHttpClassifier 

pub struct StandardHttpClassifier<B = ()> { /* private fields */ }
A standard HTTP response classifier.

Generally treats all client (4xx) and server (5xx) errors as retriable, with the exception of a few specific client errors that shouldn’t be retried:

  • 400 Bad Request (likely a client-side bug)
  • 401 Unauthorized (likely a client-side misconfiguration)
  • 403 Forbidden (likely a client-side misconfiguration)
  • 413 Payload Too Large (likely a client-side bug)

Additional HttpRetryPredicates can be registered via StandardHttpClassifier::with_predicate. A response is retried if any predicate—including the default—returns true (OR semantics). This allows callers to selectively unlock retries for status codes that the default predicate would not retry, without affecting other status codes.

Implementations

Source

impl<B: 'static> StandardHttpClassifier<B>

pub fn new() -> Self

Creates a new StandardHttpClassifier with the default status-code predicate installed.

pub fn with_predicate(self, predicate: HttpRetryPredicate<B>) -> Self

Adds a predicate.

A response is retried if any predicate—including the default—returns true (OR semantics).