HttpRetryPredicate

Type Alias HttpRetryPredicate 

pub type HttpRetryPredicate<B = ()> = Arc<dyn Fn(&Response<B>) -> bool + Send + Sync>;
A predicate that decides whether a response should be treated as retriable.

The predicate receives the response and returns true if the response should be retried.

Aliased Type

pub struct HttpRetryPredicate<B = ()> { /* private fields */ }